@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
@@ -14,9 +14,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-github-webhook",
-    "1.0.77",
+    "1.0.79",
     __name__[0:-6],
-    "cdk-github-webhook@1.0.77.jsii.tgz",
+    "cdk-github-webhook@1.0.79.jsii.tgz",
 )
 
 __all__ = [
